import { BasicEvent } from "@skeldjs/events";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player becomes the host of the room.
 *
 * This event contains a `setHost` method that does not do anything in SkeldJS
 * as the host of the room is decided by the server, making it impossible to alter
 * the host as a client.
 *
 * A server implementation may implement this by overriding the functions in
 * {@link Hostable} responsible for updating the host.
 */
export declare class PlayerSetHostEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    static eventName: "player.sethost";
    eventName: "player.sethost";
    private _alteredHost;
    constructor(room: RoomType, player: PlayerData<RoomType>);
    /**
     * The altered player that will be made host instead, if changed.
     */
    get alteredHost(): PlayerData<RoomType>;
    /**
     * Change the player that was made host.
     * @param player The player to make host.
     */
    setHost(player: PlayerData<RoomType>): void;
}
//# sourceMappingURL=SetHost.d.ts.map