"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetStartCounterEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player (i.e. the host of the room) sets the starting counter
 * located above the game code while in the lobby.
 */
class PlayerSetStartCounterEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The old value of the counter.
     */
    oldCounter, 
    /**
     * The new value of the counter.
     */
    newCounter) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldCounter = oldCounter;
        this.newCounter = newCounter;
        this.eventName = "player.setstartcounter";
        this._alteredCounter = newCounter;
    }
    /**
     * The altered value of the counter that will be set instead, if changed,
     */
    get alteredCounter() {
        return this._alteredCounter;
    }
    /**
     * Revert the counter to its old value.
     */
    revert() {
        this.setCounter(this.oldCounter);
    }
    /**
     * Change the value of the counter that was set.
     * @param counter The value of the counter to set.
     */
    setCounter(counter) {
        this._alteredCounter = counter;
    }
}
exports.PlayerSetStartCounterEvent = PlayerSetStartCounterEvent;
PlayerSetStartCounterEvent.eventName = "player.setstartcounter";
//# sourceMappingURL=SetStartCounter.js.map