import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SpawnType } from "@skeldjs/constant";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { Networkable, NetworkableEvents } from "../../Networkable";
import { PlayerDataResolvable, Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { GameData } from "../GameData";
export interface VoteBanSystemData {
    voted: Map<number, [PlayerData, PlayerData, PlayerData]>;
}
export declare type VoteBanSystemEvents<RoomType extends Hostable = Hostable> = NetworkableEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a room object for handling vote kicks.
 *
 * See {@link VoteBanSystemEvents} for events to listen to.
 */
export declare class VoteBanSystem<RoomType extends Hostable = Hostable> extends Networkable<VoteBanSystemData, VoteBanSystemEvents, RoomType> {
    /**
     * The accumulated votes.
     */
    voted: Map<number, [PlayerData<RoomType> | undefined, PlayerData<RoomType> | undefined, PlayerData<RoomType> | undefined]>;
    constructor(room: RoomType, spawnType: SpawnType, netId: number, ownerid: number, flags: number, data?: HazelReader | VoteBanSystemData, gameData?: GameData<RoomType>);
    get owner(): RoomType;
    Deserialize(reader: HazelReader, spawn?: boolean): void;
    Serialize(writer: HazelWriter, spawn?: boolean): boolean;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    private _handleAddVote;
    private _addVote;
    private _rpcAddVote;
    /**
     * Add the vote of a player to vote for another player to be kicked.
     * @param voter The player to count the vote as.
     * @param target The player to vote to be kicked.
     * @example
     *```typescript
     * room.votebansystem.addVote(client.me, player);
     * ```
     */
    addVote(voter: PlayerDataResolvable, target: PlayerDataResolvable): void;
}
//# sourceMappingURL=VoteBanSystem.d.ts.map